Learn R Programming

SAFARI (version 0.1.0)

SAFARI-package: Shape Analysis for AI-Reconstructed Images

Description

The R package SAFARI provides functions for image processing and shape analysis of regions of interest (ROI) in AI-reconstructed images.

Arguments

Details

The main functions are summarized as follows:

  • read.image: loads and preprocesses reconstructed binary images for segmentation;

  • binary.segmentation: ROI segmentation and optional feature extraction;

  • compute.features: feature extraction for an individual ROI;

  • rc.plot: visualize reconstructed binary or segmented images.

See the package vignettes for more introduction and demonstration.